---
title: <span class="badge object-type-enum"></span> HeatmapSelectionMode
---
# <span class="badge object-type-enum"></span> HeatmapSelectionMode

Controls which axis to allow selection on

## Definition

```python
class HeatmapSelectionMode(enum.StrEnum):
    """
    Controls which axis to allow selection on
    """

    X = "x"
    Y = "y"
    XY = "xy"
```
